# MuNG

The ``mung`` (**Mu**sic **N**otation **G**raph) package implements a graph representation
 of music notation that is especially amenable to Optical Music Recognition (OMR).
It was used for instance in the [MUSCIMA++](https://ufal.mff.cuni.cz/muscima) dataset of music notation.

[![Build Status](https://travis-ci.org/OMR-Research/mung.svg?branch=master)](https://travis-ci.org/OMR-Research/mung)
[![PyPI version](https://badge.fury.io/py/mung.svg)](https://badge.fury.io/py/mung)
[![Documentation Status](https://readthedocs.org/projects/mung/badge/?version=latest)](https://mung.readthedocs.io/en/latest/?badge=latest)
[![License: CC BY-NC-SA 4.0](https://img.shields.io/badge/License-MIT-brightgreen.svg)](LICENSE.txt)
[![codecov](https://codecov.io/gh/OMR-Research/mung/branch/master/graph/badge.svg)](https://codecov.io/gh/OMR-Research/mung)

Requires Python >= 3.6.


## Getting started

1. Install this package: ``pip install mung``
2. Download the [MUSCIMA++ dataset](https://github.com/OMR-Research/muscima-pp).
3. Run through the [tutorial](https://muscima.readthedocs.io/en/latest/Tutorial.html#tutorial).



## Dataset
The dataset itself is available for download
[here](https://github.com/OMR-Research/muscima-pp) and due to its derived nature, licensed differently:

[![abc](https://img.shields.io/badge/Dataset_Version-2.0-brightgreen.svg)](https://github.com/OMR-Research/muscima-pp)
[![License: CC BY-NC-SA 4.0](https://img.shields.io/badge/License-CC%20BY--NC--SA%204.0-blue.svg)](https://creativecommons.org/licenses/by-nc-sa/4.0/)
